[![Coverage](https://codecov.io/gh/laminlabs/bionty/branch/main/graph/badge.svg?token=8292E0S0Z7)](https://codecov.io/gh/laminlabs/bionty)
[![pypi](https://img.shields.io/pypi/v/bionty?color=%2334D058&label=pypi%20package)](https://pypi.org/project/bionty)

# Bionty: Open data model for biology

This package is in private beta at this moment!

Follow https://twitter.com/laminlabs to learn about a first public release.

For beta users: Read the [docs](https://lamin.ai/docs/bionty).
